@@ -1,7 +1,6 @@
 package Net::Stripe::LineItem;
-$Net::Stripe::LineItem::VERSION = '0.42_002'; # TRIAL
-$Net::Stripe::LineItem::VERSION = '0.42002';
 use Moose;
+use MooseX::Method::Signatures;
 
 # ABSTRACT: represent an Line Item object from Stripe
 
@@ -30,7 +29,7 @@ Net::Stripe::LineItem - represent an Line Item object from Stripe
 
 =head1 VERSION
 
-version 0.42_002
+version 0.14
 
 =head1 ATTRIBUTES
 
@@ -116,7 +115,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
+This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
