@@ -1,8 +1,6 @@
 package Net::Stripe::List;
-$Net::Stripe::List::VERSION = '0.42_002'; # TRIAL
-$Net::Stripe::List::VERSION = '0.42002';
 use Moose;
-use Kavorka;
+use MooseX::Method::Signatures;
 
 # ABSTRACT: represent a list of objects from Stripe
 
@@ -10,8 +8,8 @@ has 'count'    => (is => 'ro', isa => 'Maybe[Int]'); # no longer included by def
 has 'url'      => (is => 'ro', isa => 'Str', required => 1);
 has 'has_more' => (is => 'ro', isa => 'Bool|Object', required => 1);
 has 'data'     => (traits => ['Array'],
-                   is => 'ro',
-                   isa => 'ArrayRef',
+                   is => 'ro', 
+                   isa => 'ArrayRef', 
                    required => 1,
                    handles => {
                        elements => 'elements',
@@ -28,32 +26,6 @@ method last {
     return $self->get(scalar($self->elements)-1);
 }
 
-method _next_page_args() {
-    return (
-        starting_after => $self->get(-1)->id,
-    );
-}
-
-method _previous_page_args() {
-    return (
-        ending_before => $self->get(0)->id,
-    );
-}
-
-fun _merge_lists(
-    ArrayRef[Net::Stripe::List] :$lists!,
-) {
-    my $has_count = defined( $lists->[-1]->count );
-    my $url = $lists->[-1]->url;
-    my %list_args = (
-        count => $has_count ? scalar( map { $_->elements } @$lists ) : undef,
-        data => [ map { $_->elements } @$lists ],
-        has_more => 0,
-        url => $url,
-    );
-    return Net::Stripe::List->new( %list_args );
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -67,7 +39,7 @@ Net::Stripe::List - represent a list of objects from Stripe
 
 =head1 VERSION
 
-version 0.42_002
+version 0.14
 
 =head1 ATTRIBUTES
 
@@ -117,7 +89,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
+This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
