@@ -6,8 +6,6 @@ extends 'Net::Stripe::Resource';
 
 # ABSTRACT: represent a Plan object from Stripe
 
-union 'StripePlan', ['Str', 'Net::Stripe::Plan'];
-
 subtype 'StatementDescription',
     as 'Str',
     where { !defined($_) || $_ =~ /^[^<>"']{0,15}$/ },
@@ -43,7 +41,67 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.13
+version 0.14
+
+=head1 ATTRIBUTES
+
+=head2 amount
+
+Reader: amount
+
+Type: Maybe[Int]
+
+This attribute is required.
+
+=head2 currency
+
+Reader: currency
+
+Type: Maybe[Str]
+
+This attribute is required.
+
+=head2 id
+
+Reader: id
+
+Type: Maybe[Str]
+
+This attribute is required.
+
+=head2 interval
+
+Reader: interval
+
+Type: Maybe[Str]
+
+This attribute is required.
+
+=head2 interval_count
+
+Reader: interval_count
+
+Type: Maybe[Int]
+
+=head2 name
+
+Reader: name
+
+Type: Maybe[Str]
+
+This attribute is required.
+
+=head2 statement_description
+
+Reader: statement_description
+
+Type: Maybe[StatementDescription]
+
+=head2 trial_period_days
+
+Reader: trial_period_days
+
+Type: Maybe[Int]
 
 =head1 AUTHORS
 
